/**
 * Copyright (c) 2013, 2020 Borland Software Corporation, CEA LIST, Artal and others
 * 
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License 2.0
 * which accompanies this distribution, and is available at
 * https://www.eclipse.org/legal/epl-2.0/
 * 
 * SPDX-License-Identifier: EPL-2.0
 * 
 * Contributors:
 *    Svyatoslav Kovalsky (Montages) - initial API and implementation
 *    Aurelien Didier (ARTAL) - aurelien.didier51@gmail.com - Bug 569174
 */
package xpt.diagram.editpolicies;

import com.google.inject.Inject;
import com.google.inject.Singleton;
import org.eclipse.papyrus.gmf.codegen.gmfgen.GenDiagram;
import org.eclipse.xtend2.lib.StringConcatenation;
import org.eclipse.xtext.xbase.lib.Extension;
import xpt.CodeStyle;
import xpt.Common;

/**
 * FIXME: [MG] - reverse the calls? call common code from here and TextelectionEP and not vice versa
 */
@Singleton
@SuppressWarnings("all")
public class TextSelectionEditPolicy {
  @Inject
  @Extension
  private Common _common;
  
  @Inject
  private CodeStyle xptCodeStyle;
  
  public CharSequence className(final GenDiagram it) {
    StringConcatenation _builder = new StringConcatenation();
    String _textSelectionEditPolicyClassName = it.getTextSelectionEditPolicyClassName();
    _builder.append(_textSelectionEditPolicyClassName);
    return _builder;
  }
  
  public CharSequence packageName(final GenDiagram it) {
    StringConcatenation _builder = new StringConcatenation();
    String _editPoliciesPackageName = it.getEditPoliciesPackageName();
    _builder.append(_editPoliciesPackageName);
    return _builder;
  }
  
  public CharSequence qualifiedClassName(final GenDiagram it) {
    StringConcatenation _builder = new StringConcatenation();
    CharSequence _packageName = this.packageName(it);
    _builder.append(_packageName);
    _builder.append(".");
    CharSequence _className = this.className(it);
    _builder.append(_className);
    return _builder;
  }
  
  public CharSequence fullPath(final GenDiagram it) {
    StringConcatenation _builder = new StringConcatenation();
    CharSequence _qualifiedClassName = this.qualifiedClassName(it);
    _builder.append(_qualifiedClassName);
    return _builder;
  }
  
  public CharSequence TextSelectionEditPolicy_extendsClause(final GenDiagram it) {
    StringConcatenation _builder = new StringConcatenation();
    _builder.append("extends org.eclipse.gef.editpolicies.SelectionEditPolicy");
    return _builder;
  }
  
  public CharSequence TextSelectionEditPolicy_implementsClause(final GenDiagram it) {
    StringConcatenation _builder = new StringConcatenation();
    _builder.append("implements org.eclipse.gmf.tooling.runtime.edit.policies.labels.IRefreshableFeedbackEditPolicy");
    return _builder;
  }
  
  public CharSequence TextSelectionEditPolicy_additions(final GenDiagram it) {
    StringConcatenation _builder = new StringConcatenation();
    return _builder;
  }
  
  public CharSequence TextSelectionEditPolicyInvocation(final GenDiagram it) {
    StringConcatenation _builder = new StringConcatenation();
    CharSequence _TextSelectionEditPolicy = this.TextSelectionEditPolicy(it);
    _builder.append(_TextSelectionEditPolicy);
    return _builder;
  }
  
  public CharSequence TextSelectionEditPolicy(final GenDiagram it) {
    StringConcatenation _builder = new StringConcatenation();
    CharSequence _copyright = this._common.copyright(it.getEditorGen());
    _builder.append(_copyright);
    _builder.newLineIfNotEmpty();
    _builder.append("package ");
    CharSequence _packageName = this.packageName(it);
    _builder.append(_packageName);
    _builder.append(";");
    _builder.newLineIfNotEmpty();
    _builder.newLine();
    CharSequence _generatedClassComment = this._common.generatedClassComment();
    _builder.append(_generatedClassComment);
    _builder.newLineIfNotEmpty();
    _builder.append("public class ");
    CharSequence _className = this.className(it);
    _builder.append(_className);
    _builder.append(" ");
    CharSequence _TextSelectionEditPolicy_extendsClause = this.TextSelectionEditPolicy_extendsClause(it);
    _builder.append(_TextSelectionEditPolicy_extendsClause);
    _builder.append(" ");
    CharSequence _TextSelectionEditPolicy_implementsClause = this.TextSelectionEditPolicy_implementsClause(it);
    _builder.append(_TextSelectionEditPolicy_implementsClause);
    _builder.append(" {");
    _builder.newLineIfNotEmpty();
    _builder.newLine();
    _builder.append("\t");
    CharSequence _textFeedback = this.textFeedback(it);
    _builder.append(_textFeedback, "\t");
    _builder.newLineIfNotEmpty();
    _builder.append("\t");
    _builder.newLine();
    _builder.append("\t");
    CharSequence _TextSelectionEditPolicy_additions = this.TextSelectionEditPolicy_additions(it);
    _builder.append(_TextSelectionEditPolicy_additions, "\t");
    _builder.newLineIfNotEmpty();
    _builder.append("}");
    _builder.newLine();
    return _builder;
  }
  
  public CharSequence textFeedback(final GenDiagram it) {
    StringConcatenation _builder = new StringConcatenation();
    CharSequence _textFeedback_fields = this.textFeedback_fields(it);
    _builder.append(_textFeedback_fields);
    _builder.append(" ");
    _builder.newLineIfNotEmpty();
    _builder.newLine();
    CharSequence _textFeedback_showPrimarySelection = this.textFeedback_showPrimarySelection(it);
    _builder.append(_textFeedback_showPrimarySelection);
    _builder.newLineIfNotEmpty();
    _builder.newLine();
    CharSequence _textFeedback_showSelection = this.textFeedback_showSelection(it);
    _builder.append(_textFeedback_showSelection);
    _builder.newLineIfNotEmpty();
    _builder.newLine();
    CharSequence _textFeedback_hideSelection = this.textFeedback_hideSelection(it);
    _builder.append(_textFeedback_hideSelection);
    _builder.newLineIfNotEmpty();
    _builder.newLine();
    CharSequence _textFeedback_showFocus = this.textFeedback_showFocus(it);
    _builder.append(_textFeedback_showFocus);
    _builder.newLineIfNotEmpty();
    _builder.newLine();
    CharSequence _textFeedback_hideFocus = this.textFeedback_hideFocus(it);
    _builder.append(_textFeedback_hideFocus);
    _builder.newLineIfNotEmpty();
    _builder.newLine();
    CharSequence _textFeedback_getFeedbackBounds = this.textFeedback_getFeedbackBounds(it);
    _builder.append(_textFeedback_getFeedbackBounds);
    _builder.newLineIfNotEmpty();
    _builder.newLine();
    CharSequence _textFeedback_createSelectionFeedbackFigure = this.textFeedback_createSelectionFeedbackFigure(it);
    _builder.append(_textFeedback_createSelectionFeedbackFigure);
    _builder.newLineIfNotEmpty();
    _builder.newLine();
    CharSequence _textFeedback_createFocusFeedbackFigure = this.textFeedback_createFocusFeedbackFigure(it);
    _builder.append(_textFeedback_createFocusFeedbackFigure);
    _builder.newLineIfNotEmpty();
    _builder.newLine();
    CharSequence _textFeedback_updateLabel = this.textFeedback_updateLabel(it);
    _builder.append(_textFeedback_updateLabel);
    _builder.newLineIfNotEmpty();
    _builder.newLine();
    CharSequence _textFeedback_refreshSelectionFeedback = this.textFeedback_refreshSelectionFeedback(it);
    _builder.append(_textFeedback_refreshSelectionFeedback);
    _builder.newLineIfNotEmpty();
    _builder.newLine();
    CharSequence _textFeedback_refreshFocusFeedback = this.textFeedback_refreshFocusFeedback(it);
    _builder.append(_textFeedback_refreshFocusFeedback);
    _builder.newLineIfNotEmpty();
    _builder.newLine();
    CharSequence _textFeedback_refreshFeedback = this.textFeedback_refreshFeedback(it);
    _builder.append(_textFeedback_refreshFeedback);
    _builder.newLineIfNotEmpty();
    _builder.newLine();
    CharSequence _textFeedback_getHostPositionListener = this.textFeedback_getHostPositionListener(it);
    _builder.append(_textFeedback_getHostPositionListener);
    _builder.newLineIfNotEmpty();
    return _builder;
  }
  
  public CharSequence textFeedback_fields(final GenDiagram it) {
    StringConcatenation _builder = new StringConcatenation();
    CharSequence _generatedMemberComment = this._common.generatedMemberComment();
    _builder.append(_generatedMemberComment);
    _builder.newLineIfNotEmpty();
    _builder.append("private org.eclipse.draw2d.IFigure selectionFeedbackFigure;");
    _builder.newLine();
    _builder.newLine();
    CharSequence _generatedMemberComment_1 = this._common.generatedMemberComment();
    _builder.append(_generatedMemberComment_1);
    _builder.newLineIfNotEmpty();
    _builder.append("private org.eclipse.draw2d.IFigure focusFeedbackFigure;");
    _builder.newLine();
    _builder.newLine();
    CharSequence _generatedMemberComment_2 = this._common.generatedMemberComment();
    _builder.append(_generatedMemberComment_2);
    _builder.newLineIfNotEmpty();
    _builder.append("private org.eclipse.draw2d.FigureListener hostPositionListener;");
    _builder.newLine();
    return _builder;
  }
  
  public CharSequence textFeedback_showPrimarySelection(final GenDiagram it) {
    StringConcatenation _builder = new StringConcatenation();
    CharSequence _generatedMemberComment = this._common.generatedMemberComment();
    _builder.append(_generatedMemberComment);
    _builder.newLineIfNotEmpty();
    _builder.append("protected void showPrimarySelection() {");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("if (getHostFigure() instanceof org.eclipse.gmf.runtime.draw2d.ui.figures.WrappingLabel) {");
    _builder.newLine();
    _builder.append("\t\t");
    _builder.append("((org.eclipse.gmf.runtime.draw2d.ui.figures.WrappingLabel) getHostFigure()).setSelected(true);");
    _builder.newLine();
    _builder.append("\t\t");
    _builder.append("((org.eclipse.gmf.runtime.draw2d.ui.figures.WrappingLabel) getHostFigure()).setFocus(true);");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("} else {");
    _builder.newLine();
    _builder.append("\t\t");
    _builder.append("showSelection();");
    _builder.newLine();
    _builder.append("\t\t");
    _builder.append("showFocus();");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("}");
    _builder.newLine();
    _builder.append("}");
    _builder.newLine();
    return _builder;
  }
  
  public CharSequence textFeedback_showSelection(final GenDiagram it) {
    StringConcatenation _builder = new StringConcatenation();
    CharSequence _generatedMemberComment = this._common.generatedMemberComment();
    _builder.append(_generatedMemberComment);
    _builder.newLineIfNotEmpty();
    _builder.append("protected void showSelection() {");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("if (getHostFigure() instanceof org.eclipse.gmf.runtime.draw2d.ui.figures.WrappingLabel) {");
    _builder.newLine();
    _builder.append("\t\t");
    _builder.append("((org.eclipse.gmf.runtime.draw2d.ui.figures.WrappingLabel) getHostFigure()).setSelected(true);");
    _builder.newLine();
    _builder.append("\t\t");
    _builder.append("((org.eclipse.gmf.runtime.draw2d.ui.figures.WrappingLabel) getHostFigure()).setFocus(false);");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("} else {");
    _builder.newLine();
    _builder.append("\t\t");
    _builder.append("hideSelection();");
    _builder.newLine();
    _builder.append("\t\t");
    _builder.append("addFeedback(selectionFeedbackFigure = createSelectionFeedbackFigure());");
    _builder.newLine();
    _builder.append("\t\t");
    _builder.append("getHostFigure().addFigureListener(getHostPositionListener());");
    _builder.newLine();
    _builder.append("\t\t");
    _builder.append("refreshSelectionFeedback();");
    _builder.newLine();
    _builder.append("\t\t");
    _builder.append("hideFocus();");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("}");
    _builder.newLine();
    _builder.append("}");
    _builder.newLine();
    return _builder;
  }
  
  public CharSequence textFeedback_hideSelection(final GenDiagram it) {
    StringConcatenation _builder = new StringConcatenation();
    CharSequence _generatedMemberComment = this._common.generatedMemberComment();
    _builder.append(_generatedMemberComment);
    _builder.newLineIfNotEmpty();
    _builder.append("protected void hideSelection() {");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("if (getHostFigure() instanceof org.eclipse.gmf.runtime.draw2d.ui.figures.WrappingLabel) {");
    _builder.newLine();
    _builder.append("\t\t");
    _builder.append("((org.eclipse.gmf.runtime.draw2d.ui.figures.WrappingLabel) getHostFigure()).setSelected(false);");
    _builder.newLine();
    _builder.append("\t\t");
    _builder.append("((org.eclipse.gmf.runtime.draw2d.ui.figures.WrappingLabel) getHostFigure()).setFocus(false);");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("} else {");
    _builder.newLine();
    _builder.append("\t\t");
    _builder.append("if (selectionFeedbackFigure != null) {");
    _builder.newLine();
    _builder.append("\t\t\t");
    _builder.append("removeFeedback(selectionFeedbackFigure);");
    _builder.newLine();
    _builder.append("\t\t\t");
    _builder.append("getHostFigure().removeFigureListener(getHostPositionListener());");
    _builder.newLine();
    _builder.append("\t\t\t");
    _builder.append("selectionFeedbackFigure = null;");
    _builder.newLine();
    _builder.append("\t\t");
    _builder.append("}");
    _builder.newLine();
    _builder.append("\t\t");
    _builder.append("hideFocus();");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("}");
    _builder.newLine();
    _builder.append("}");
    _builder.newLine();
    return _builder;
  }
  
  public CharSequence textFeedback_showFocus(final GenDiagram it) {
    StringConcatenation _builder = new StringConcatenation();
    CharSequence _generatedMemberComment = this._common.generatedMemberComment();
    _builder.append(_generatedMemberComment);
    _builder.newLineIfNotEmpty();
    _builder.append("protected void showFocus() {");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("if (getHostFigure() instanceof org.eclipse.gmf.runtime.draw2d.ui.figures.WrappingLabel) {");
    _builder.newLine();
    _builder.append("\t\t");
    _builder.append("((org.eclipse.gmf.runtime.draw2d.ui.figures.WrappingLabel) getHostFigure()).setFocus(true);");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("} else {");
    _builder.newLine();
    _builder.append("\t\t");
    _builder.append("hideFocus();");
    _builder.newLine();
    _builder.append("\t\t");
    _builder.append("addFeedback(focusFeedbackFigure = createFocusFeedbackFigure());");
    _builder.newLine();
    _builder.append("\t\t");
    _builder.append("refreshFocusFeedback();");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("}");
    _builder.newLine();
    _builder.append("}");
    _builder.newLine();
    return _builder;
  }
  
  public CharSequence textFeedback_hideFocus(final GenDiagram it) {
    StringConcatenation _builder = new StringConcatenation();
    CharSequence _generatedMemberComment = this._common.generatedMemberComment();
    _builder.append(_generatedMemberComment);
    _builder.newLineIfNotEmpty();
    _builder.append("protected void hideFocus() {");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("if (getHostFigure() instanceof org.eclipse.gmf.runtime.draw2d.ui.figures.WrappingLabel) {");
    _builder.newLine();
    _builder.append("\t\t");
    _builder.append("((org.eclipse.gmf.runtime.draw2d.ui.figures.WrappingLabel) getHostFigure()).setFocus(false);");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("} else {");
    _builder.newLine();
    _builder.append("\t\t");
    _builder.append("if (focusFeedbackFigure != null) {");
    _builder.newLine();
    _builder.append("\t\t\t");
    _builder.append("removeFeedback(focusFeedbackFigure);");
    _builder.newLine();
    _builder.append("\t\t\t");
    _builder.append("focusFeedbackFigure = null;");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("}");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("}");
    _builder.newLine();
    _builder.append("}");
    _builder.newLine();
    return _builder;
  }
  
  public CharSequence textFeedback_getFeedbackBounds(final GenDiagram it) {
    StringConcatenation _builder = new StringConcatenation();
    CharSequence _generatedMemberComment = this._common.generatedMemberComment();
    _builder.append(_generatedMemberComment);
    _builder.newLineIfNotEmpty();
    _builder.append("protected org.eclipse.draw2d.geometry.Rectangle getFeedbackBounds() {");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("org.eclipse.draw2d.geometry.Rectangle bounds;");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("if (getHostFigure() instanceof org.eclipse.draw2d.Label) {");
    _builder.newLine();
    _builder.append("\t\t");
    _builder.append("bounds = ((org.eclipse.draw2d.Label) getHostFigure()).getTextBounds();");
    _builder.newLine();
    _builder.append("\t\t");
    _builder.append("bounds.intersect(getHostFigure().getBounds());");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("} else {");
    _builder.newLine();
    _builder.append("\t\t");
    _builder.append("bounds = getHostFigure().getBounds().getCopy();");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("}");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("getHostFigure().getParent().translateToAbsolute(bounds);");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("getFeedbackLayer().translateToRelative(bounds);");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("return bounds;");
    _builder.newLine();
    _builder.append("}");
    _builder.newLine();
    return _builder;
  }
  
  public CharSequence textFeedback_createSelectionFeedbackFigure(final GenDiagram it) {
    StringConcatenation _builder = new StringConcatenation();
    CharSequence _generatedMemberComment = this._common.generatedMemberComment();
    _builder.append(_generatedMemberComment);
    _builder.newLineIfNotEmpty();
    _builder.append("protected org.eclipse.draw2d.IFigure createSelectionFeedbackFigure() {");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("if (getHostFigure() instanceof org.eclipse.draw2d.Label) {");
    _builder.newLine();
    _builder.append("\t\t");
    _builder.append("org.eclipse.draw2d.Label feedbackFigure = new org.eclipse.draw2d.Label();");
    _builder.newLine();
    _builder.append("\t\t");
    _builder.append("feedbackFigure.setOpaque(true);");
    _builder.newLine();
    _builder.append("\t\t");
    _builder.append("feedbackFigure.setBackgroundColor(org.eclipse.draw2d.ColorConstants.menuBackgroundSelected);");
    _builder.newLine();
    _builder.append("\t\t");
    _builder.append("feedbackFigure.setForegroundColor(org.eclipse.draw2d.ColorConstants.menuForegroundSelected);");
    _builder.newLine();
    _builder.append("\t\t");
    _builder.append("return feedbackFigure;");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("} else {");
    _builder.newLine();
    _builder.append("\t\t");
    _builder.append("org.eclipse.draw2d.RectangleFigure feedbackFigure = new org.eclipse.draw2d.RectangleFigure();");
    _builder.newLine();
    _builder.append("\t\t");
    _builder.append("feedbackFigure.setFill(false);");
    _builder.newLine();
    _builder.append("\t\t");
    _builder.append("return feedbackFigure;");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("}");
    _builder.newLine();
    _builder.append("}");
    _builder.newLine();
    return _builder;
  }
  
  public CharSequence textFeedback_createFocusFeedbackFigure(final GenDiagram it) {
    StringConcatenation _builder = new StringConcatenation();
    CharSequence _generatedMemberComment = this._common.generatedMemberComment();
    _builder.append(_generatedMemberComment);
    _builder.newLineIfNotEmpty();
    _builder.append("protected org.eclipse.draw2d.IFigure createFocusFeedbackFigure() {");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("return new org.eclipse.draw2d.Figure() {");
    _builder.newLine();
    _builder.newLine();
    _builder.append("\t");
    _builder.append("protected void paintFigure(org.eclipse.draw2d.Graphics graphics) {");
    _builder.newLine();
    _builder.append("\t\t");
    _builder.append("graphics.drawFocus(getBounds().getResized(-1, -1));");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("}");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("};");
    _builder.newLine();
    _builder.append("}");
    _builder.newLine();
    return _builder;
  }
  
  public CharSequence textFeedback_updateLabel(final GenDiagram it) {
    StringConcatenation _builder = new StringConcatenation();
    CharSequence _generatedMemberComment = this._common.generatedMemberComment();
    _builder.append(_generatedMemberComment);
    _builder.newLineIfNotEmpty();
    _builder.append("protected void updateLabel(org.eclipse.draw2d.Label target) {");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("org.eclipse.draw2d.Label source = (org.eclipse.draw2d.Label) getHostFigure();");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("target.setText(source.getText());");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("target.setTextAlignment(source.getTextAlignment());");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("target.setFont(source.getFont());");
    _builder.newLine();
    _builder.append("}");
    _builder.newLine();
    return _builder;
  }
  
  public CharSequence textFeedback_refreshSelectionFeedback(final GenDiagram it) {
    StringConcatenation _builder = new StringConcatenation();
    CharSequence _generatedMemberComment = this._common.generatedMemberComment();
    _builder.append(_generatedMemberComment);
    _builder.newLineIfNotEmpty();
    _builder.append("protected void refreshSelectionFeedback() {");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("if (selectionFeedbackFigure != null) {");
    _builder.newLine();
    _builder.append("\t\t");
    _builder.append("if (selectionFeedbackFigure instanceof org.eclipse.draw2d.Label) {");
    _builder.newLine();
    _builder.append("\t\t\t");
    _builder.append("updateLabel((org.eclipse.draw2d.Label) selectionFeedbackFigure);");
    _builder.newLine();
    _builder.append("\t\t\t");
    _builder.append("selectionFeedbackFigure.setBounds(getFeedbackBounds());");
    _builder.newLine();
    _builder.append("\t\t");
    _builder.append("} else {");
    _builder.newLine();
    _builder.append("\t\t\t");
    _builder.append("selectionFeedbackFigure.setBounds(getFeedbackBounds().expand(5, 5));");
    _builder.newLine();
    _builder.append("\t\t");
    _builder.append("}");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("}");
    _builder.newLine();
    _builder.append("}");
    _builder.newLine();
    return _builder;
  }
  
  public CharSequence textFeedback_refreshFocusFeedback(final GenDiagram it) {
    StringConcatenation _builder = new StringConcatenation();
    CharSequence _generatedMemberComment = this._common.generatedMemberComment();
    _builder.append(_generatedMemberComment);
    _builder.newLineIfNotEmpty();
    _builder.append("protected void refreshFocusFeedback() {");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("if (focusFeedbackFigure != null) {");
    _builder.newLine();
    _builder.append("\t\t");
    _builder.append("focusFeedbackFigure.setBounds(getFeedbackBounds());");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("}");
    _builder.newLine();
    _builder.append("}");
    _builder.newLine();
    return _builder;
  }
  
  public CharSequence textFeedback_refreshFeedback(final GenDiagram it) {
    StringConcatenation _builder = new StringConcatenation();
    CharSequence _generatedMemberComment = this._common.generatedMemberComment();
    _builder.append(_generatedMemberComment);
    _builder.newLineIfNotEmpty();
    CharSequence _overrideI = this.xptCodeStyle.overrideI(it);
    _builder.append(_overrideI);
    _builder.newLineIfNotEmpty();
    _builder.append("public void refreshFeedback() {");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("refreshSelectionFeedback();");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("refreshFocusFeedback();");
    _builder.newLine();
    _builder.append("}");
    _builder.newLine();
    return _builder;
  }
  
  public CharSequence textFeedback_getHostPositionListener(final GenDiagram it) {
    StringConcatenation _builder = new StringConcatenation();
    CharSequence _generatedMemberComment = this._common.generatedMemberComment();
    _builder.append(_generatedMemberComment);
    _builder.newLineIfNotEmpty();
    _builder.append("private org.eclipse.draw2d.FigureListener getHostPositionListener() {");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("if (hostPositionListener == null) {");
    _builder.newLine();
    _builder.append("\t\t");
    _builder.append("hostPositionListener = new org.eclipse.draw2d.FigureListener() {");
    _builder.newLine();
    _builder.append("\t\t\t");
    _builder.append("public void figureMoved(org.eclipse.draw2d.IFigure source) {");
    _builder.newLine();
    _builder.append("\t\t\t\t");
    _builder.append("refreshFeedback();");
    _builder.newLine();
    _builder.append("\t\t\t");
    _builder.append("}");
    _builder.newLine();
    _builder.append("\t\t");
    _builder.append("};");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("}");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("return hostPositionListener;");
    _builder.newLine();
    _builder.append("}");
    _builder.newLine();
    return _builder;
  }
}
