/**
 * Copyright (c) 2007, 2020 Borland Software Corporation, CEA LIST, Artal and others
 * 
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License 2.0
 * which accompanies this distribution, and is available at
 * https://www.eclipse.org/legal/epl-2.0/
 * 
 * SPDX-License-Identifier: EPL-2.0
 * 
 * Contributors:
 *    Dmitry Stadnik (Borland) - initial API and implementation
 * 	  Michael Golubev (Montages) - #386838 - migrate to Xtend2
 */
package xpt.providers;

import com.google.common.base.Objects;
import com.google.common.collect.Iterables;
import com.google.inject.Inject;
import com.google.inject.Singleton;
import java.util.Arrays;
import java.util.List;
import org.eclipse.emf.codegen.ecore.genmodel.GenClass;
import org.eclipse.emf.common.util.EList;
import org.eclipse.papyrus.gmf.codegen.gmfgen.ElementType;
import org.eclipse.papyrus.gmf.codegen.gmfgen.GenCommonBase;
import org.eclipse.papyrus.gmf.codegen.gmfgen.GenContainerBase;
import org.eclipse.papyrus.gmf.codegen.gmfgen.GenDiagram;
import org.eclipse.papyrus.gmf.codegen.gmfgen.GenLink;
import org.eclipse.papyrus.gmf.codegen.gmfgen.GenNode;
import org.eclipse.papyrus.gmf.codegen.gmfgen.GenNodeLabel;
import org.eclipse.papyrus.gmf.codegen.gmfgen.MetamodelType;
import org.eclipse.papyrus.gmf.codegen.gmfgen.NotationType;
import org.eclipse.papyrus.gmf.codegen.gmfgen.ProviderPriority;
import org.eclipse.papyrus.gmf.codegen.gmfgen.SpecializationType;
import org.eclipse.papyrus.gmf.codegen.xtend.annotations.Localization;
import org.eclipse.papyrus.gmf.codegen.xtend.annotations.MetaDef;
import org.eclipse.xtend2.lib.StringConcatenation;
import org.eclipse.xtext.xbase.lib.Extension;
import org.eclipse.xtext.xbase.lib.Functions.Function1;
import org.eclipse.xtext.xbase.lib.ListExtensions;
import parsers.ParserProvider;
import xpt.Common;
import xpt.Common_qvto;
import xpt.diagram.Utils_qvto;
import xpt.diagram.edithelpers.EditHelper;
import xpt.diagram.edithelpers.EditHelperAdvice;

@Singleton
@SuppressWarnings("all")
public class extensions {
  @Inject
  @Extension
  private Common _common;
  
  @Inject
  @Extension
  private Common_qvto _common_qvto;
  
  @Inject
  @Extension
  private Utils_qvto _utils_qvto;
  
  @Inject
  private ViewProvider viewProvider;
  
  @Inject
  private IconProvider iconProvider;
  
  @Inject
  private EditPartProvider editPartProvider;
  
  @Inject
  private EditPartModelingAssistantProvider xptEditPartModelingAssistant;
  
  @Inject
  private ParserProvider labelParsers;
  
  @Inject
  private ShortcutsDecoratorProvider shorcutProvider;
  
  @Inject
  private EditHelper editHelper;
  
  @Inject
  private EditHelperAdvice editHelperAdvice;
  
  public CharSequence extensions(final GenDiagram it) {
    StringConcatenation _builder = new StringConcatenation();
    CharSequence _extraLineBreak = this._common.extraLineBreak();
    _builder.append(_extraLineBreak);
    _builder.newLineIfNotEmpty();
    String _tripleSpace = this._common.tripleSpace(1);
    _builder.append(_tripleSpace);
    _builder.append("<extension point=\"org.eclipse.gmf.runtime.diagram.core.viewProviders\" id=\"view-provider\">");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_1 = this._common.tripleSpace(2);
    _builder.append(_tripleSpace_1);
    CharSequence _xmlGeneratedTag = this._common.xmlGeneratedTag();
    _builder.append(_xmlGeneratedTag);
    _builder.newLineIfNotEmpty();
    String _tripleSpace_2 = this._common.tripleSpace(2);
    _builder.append(_tripleSpace_2);
    _builder.append("<viewProvider class=\"");
    CharSequence _qualifiedClassName = this.viewProvider.qualifiedClassName(it);
    _builder.append(_qualifiedClassName);
    _builder.append("\">");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_3 = this._common.tripleSpace(3);
    _builder.append(_tripleSpace_3);
    _builder.append("<Priority name=\"");
    ProviderPriority _notationViewProviderPriority = it.getNotationViewProviderPriority();
    _builder.append(_notationViewProviderPriority);
    _builder.append("\"/>");
    _builder.newLineIfNotEmpty();
    {
      boolean _notEmpty = this._common_qvto.<String>notEmpty(it.getShortcutsProvidedFor());
      if (_notEmpty) {
        String _tripleSpace_4 = this._common.tripleSpace(3);
        _builder.append(_tripleSpace_4);
        _builder.append("<object id=\"referencing-diagrams\" class=\"org.eclipse.gmf.runtime.notation.Diagram\">");
        _builder.newLineIfNotEmpty();
        String _tripleSpace_5 = this._common.tripleSpace(4);
        _builder.append(_tripleSpace_5);
        _builder.append("<method name=\"getType()\" value=\"");
        {
          EList<String> _shortcutsProvidedFor = it.getShortcutsProvidedFor();
          boolean _hasElements = false;
          for(final String s : _shortcutsProvidedFor) {
            if (!_hasElements) {
              _hasElements = true;
            } else {
              _builder.appendImmediate(",", "");
            }
            _builder.append(s);
          }
        }
        _builder.append("\"/>");
        _builder.newLineIfNotEmpty();
        String _tripleSpace_6 = this._common.tripleSpace(3);
        _builder.append(_tripleSpace_6);
        _builder.append("</object>");
        _builder.newLineIfNotEmpty();
        String _tripleSpace_7 = this._common.tripleSpace(3);
        _builder.append(_tripleSpace_7);
        _builder.append("<context viewClass=\"org.eclipse.gmf.runtime.notation.Node\" containerViews=\"referencing-diagrams\"/>");
        _builder.newLineIfNotEmpty();
      }
    }
    String _tripleSpace_8 = this._common.tripleSpace(3);
    _builder.append(_tripleSpace_8);
    _builder.append("<context viewClass=\"org.eclipse.gmf.runtime.notation.Diagram\" semanticHints=\"");
    String _modelID = it.getEditorGen().getModelID();
    _builder.append(_modelID);
    _builder.append("\"/>");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_9 = this._common.tripleSpace(3);
    _builder.append(_tripleSpace_9);
    _builder.append("<context viewClass=\"org.eclipse.gmf.runtime.notation.Node\" semanticHints=\"");
    CharSequence _commaSeparatedVisualIDs = this.commaSeparatedVisualIDs(it.getAllNodes());
    _builder.append(_commaSeparatedVisualIDs);
    _builder.append("\"/>");
    _builder.newLineIfNotEmpty();
    {
      boolean _notEmpty_1 = this._common_qvto.<GenLink>notEmpty(it.getLinks());
      if (_notEmpty_1) {
        String _tripleSpace_10 = this._common.tripleSpace(3);
        _builder.append(_tripleSpace_10);
        _builder.append("<context viewClass=\"org.eclipse.gmf.runtime.notation.Edge\" semanticHints=\"");
        CharSequence _commaSeparatedVisualIDs_1 = this.commaSeparatedVisualIDs(it.getLinks());
        _builder.append(_commaSeparatedVisualIDs_1);
        _builder.append("\"/>");
        _builder.newLineIfNotEmpty();
      }
    }
    String _tripleSpace_11 = this._common.tripleSpace(2);
    _builder.append(_tripleSpace_11);
    _builder.append("</viewProvider>");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_12 = this._common.tripleSpace(1);
    _builder.append(_tripleSpace_12);
    _builder.append("</extension>");
    _builder.newLineIfNotEmpty();
    _builder.newLine();
    String _tripleSpace_13 = this._common.tripleSpace(1);
    _builder.append(_tripleSpace_13);
    _builder.append("<extension point=\"org.eclipse.gmf.runtime.diagram.ui.editpartProviders\" id=\"ep-provider\">");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_14 = this._common.tripleSpace(2);
    _builder.append(_tripleSpace_14);
    CharSequence _xmlGeneratedTag_1 = this._common.xmlGeneratedTag();
    _builder.append(_xmlGeneratedTag_1);
    _builder.newLineIfNotEmpty();
    String _tripleSpace_15 = this._common.tripleSpace(2);
    _builder.append(_tripleSpace_15);
    _builder.append("<editpartProvider class=\"");
    CharSequence _qualifiedClassName_1 = this.editPartProvider.qualifiedClassName(it);
    _builder.append(_qualifiedClassName_1);
    _builder.append("\">");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_16 = this._common.tripleSpace(3);
    _builder.append(_tripleSpace_16);
    _builder.append("<Priority name=\"");
    ProviderPriority _editPartProviderPriority = it.getEditPartProviderPriority();
    _builder.append(_editPartProviderPriority);
    _builder.append("\"/>");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_17 = this._common.tripleSpace(3);
    _builder.append(_tripleSpace_17);
    _builder.append("<object class=\"org.eclipse.gmf.runtime.notation.Diagram\" id=\"generated-diagram\">");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_18 = this._common.tripleSpace(4);
    _builder.append(_tripleSpace_18);
    _builder.append("<method name=\"getType()\" value=\"");
    String _modelID_1 = it.getEditorGen().getModelID();
    _builder.append(_modelID_1);
    _builder.append("\"/>");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_19 = this._common.tripleSpace(3);
    _builder.append(_tripleSpace_19);
    _builder.append("</object>");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_20 = this._common.tripleSpace(3);
    _builder.append(_tripleSpace_20);
    _builder.append("<object class=\"org.eclipse.gmf.runtime.notation.Node\" id=\"generated-nodes\">");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_21 = this._common.tripleSpace(4);
    _builder.append(_tripleSpace_21);
    _builder.append("<method name=\"getType()\" value=\"");
    CharSequence _commaSeparatedVisualIDs_2 = this.commaSeparatedVisualIDs(it.getAllNodes());
    _builder.append(_commaSeparatedVisualIDs_2);
    _builder.append("\"/>");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_22 = this._common.tripleSpace(3);
    _builder.append(_tripleSpace_22);
    _builder.append("</object>");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_23 = this._common.tripleSpace(3);
    _builder.append(_tripleSpace_23);
    _builder.append("<object class=\"org.eclipse.gmf.runtime.notation.Edge\" id=\"generated-links\">");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_24 = this._common.tripleSpace(4);
    _builder.append(_tripleSpace_24);
    _builder.append("<method name=\"getType()\" value=\"");
    CharSequence _commaSeparatedVisualIDs_3 = this.commaSeparatedVisualIDs(it.getLinks());
    _builder.append(_commaSeparatedVisualIDs_3);
    _builder.append("\"/>");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_25 = this._common.tripleSpace(3);
    _builder.append(_tripleSpace_25);
    _builder.append("</object>");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_26 = this._common.tripleSpace(3);
    _builder.append(_tripleSpace_26);
    _builder.append("<object class=\"org.eclipse.gmf.runtime.notation.Node\" id=\"generated-labels\">");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_27 = this._common.tripleSpace(4);
    _builder.append(_tripleSpace_27);
    _builder.append("<method name=\"getType()\" value=\"");
    final Function1<GenNode, EList<GenNodeLabel>> _function = new Function1<GenNode, EList<GenNodeLabel>>() {
      @Override
      public EList<GenNodeLabel> apply(final GenNode n) {
        return n.getLabels();
      }
    };
    CharSequence _commaSeparatedVisualIDs_4 = this.commaSeparatedVisualIDs(Iterables.<GenNodeLabel>concat(ListExtensions.<GenNode, EList<GenNodeLabel>>map(it.getAllNodes(), _function)));
    _builder.append(_commaSeparatedVisualIDs_4);
    _builder.append("\"/>");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_28 = this._common.tripleSpace(3);
    _builder.append(_tripleSpace_28);
    _builder.append("</object>");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_29 = this._common.tripleSpace(3);
    _builder.append(_tripleSpace_29);
    _builder.append("<object class=\"org.eclipse.gmf.runtime.notation.Node\" id=\"generated-compartments\">");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_30 = this._common.tripleSpace(4);
    _builder.append(_tripleSpace_30);
    _builder.append("<method name=\"getType()\" value=\"");
    CharSequence _commaSeparatedVisualIDs_5 = this.commaSeparatedVisualIDs(it.getCompartments());
    _builder.append(_commaSeparatedVisualIDs_5);
    _builder.append("\"/>");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_31 = this._common.tripleSpace(3);
    _builder.append(_tripleSpace_31);
    _builder.append("</object>");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_32 = this._common.tripleSpace(3);
    _builder.append(_tripleSpace_32);
    _builder.append("<context views=\"generated-diagram,generated-nodes,generated-links,generated-labels,generated-compartments\"/>");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_33 = this._common.tripleSpace(2);
    _builder.append(_tripleSpace_33);
    _builder.append("</editpartProvider>");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_34 = this._common.tripleSpace(1);
    _builder.append(_tripleSpace_34);
    _builder.append("</extension>");
    _builder.newLineIfNotEmpty();
    _builder.newLine();
    CharSequence _modelingAssistantProvider = this.modelingAssistantProvider(it);
    _builder.append(_modelingAssistantProvider);
    _builder.newLineIfNotEmpty();
    _builder.newLine();
    String _tripleSpace_35 = this._common.tripleSpace(1);
    _builder.append(_tripleSpace_35);
    _builder.append("<extension point=\"org.eclipse.gmf.runtime.common.ui.services.iconProviders\" id=\"icon-provider\">");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_36 = this._common.tripleSpace(2);
    _builder.append(_tripleSpace_36);
    CharSequence _xmlGeneratedTag_2 = this._common.xmlGeneratedTag();
    _builder.append(_xmlGeneratedTag_2);
    _builder.newLineIfNotEmpty();
    String _tripleSpace_37 = this._common.tripleSpace(2);
    _builder.append(_tripleSpace_37);
    _builder.append("<IconProvider class=\"");
    CharSequence _qualifiedClassName_2 = this.iconProvider.qualifiedClassName(it);
    _builder.append(_qualifiedClassName_2);
    _builder.append("\">");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_38 = this._common.tripleSpace(3);
    _builder.append(_tripleSpace_38);
    _builder.append("<Priority name=\"");
    ProviderPriority _iconProviderPriority = it.getIconProviderPriority();
    _builder.append(_iconProviderPriority);
    _builder.append("\"/>");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_39 = this._common.tripleSpace(2);
    _builder.append(_tripleSpace_39);
    _builder.append("</IconProvider>");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_40 = this._common.tripleSpace(1);
    _builder.append(_tripleSpace_40);
    _builder.append("</extension>");
    _builder.newLineIfNotEmpty();
    {
      if (((!Objects.equal(it.getEditorGen().getLabelParsers(), null)) && it.getEditorGen().getLabelParsers().isExtensibleViaService())) {
        CharSequence _extraLineBreak_1 = this._common.extraLineBreak();
        _builder.append(_extraLineBreak_1);
        _builder.newLineIfNotEmpty();
        String _tripleSpace_41 = this._common.tripleSpace(1);
        _builder.append(_tripleSpace_41);
        _builder.append("<extension point=\"org.eclipse.gmf.runtime.common.ui.services.parserProviders\" id=\"parser-provider\">");
        _builder.newLineIfNotEmpty();
        String _tripleSpace_42 = this._common.tripleSpace(2);
        _builder.append(_tripleSpace_42);
        CharSequence _xmlGeneratedTag_3 = this._common.xmlGeneratedTag();
        _builder.append(_xmlGeneratedTag_3);
        _builder.newLineIfNotEmpty();
        String _tripleSpace_43 = this._common.tripleSpace(2);
        _builder.append(_tripleSpace_43);
        _builder.append("<ParserProvider class=\"");
        CharSequence _qualifiedClassName_3 = this.labelParsers.qualifiedClassName(it.getEditorGen().getLabelParsers());
        _builder.append(_qualifiedClassName_3);
        _builder.append("\">");
        _builder.newLineIfNotEmpty();
        String _tripleSpace_44 = this._common.tripleSpace(3);
        _builder.append(_tripleSpace_44);
        _builder.append("<Priority name=\"");
        ProviderPriority _providerPriority = it.getEditorGen().getLabelParsers().getProviderPriority();
        _builder.append(_providerPriority);
        _builder.append("\"/>");
        _builder.newLineIfNotEmpty();
        String _tripleSpace_45 = this._common.tripleSpace(2);
        _builder.append(_tripleSpace_45);
        _builder.append("</ParserProvider>");
        _builder.newLineIfNotEmpty();
        String _tripleSpace_46 = this._common.tripleSpace(1);
        _builder.append(_tripleSpace_46);
        _builder.append("</extension>");
        _builder.newLineIfNotEmpty();
      }
    }
    {
      boolean _generateShortcutIcon = it.generateShortcutIcon();
      if (_generateShortcutIcon) {
        CharSequence _extraLineBreak_2 = this._common.extraLineBreak();
        _builder.append(_extraLineBreak_2);
        _builder.newLineIfNotEmpty();
        String _tripleSpace_47 = this._common.tripleSpace(1);
        _builder.append(_tripleSpace_47);
        _builder.append("<extension point=\"org.eclipse.gmf.runtime.diagram.ui.decoratorProviders\" id=\"decorator-provider\">");
        _builder.newLineIfNotEmpty();
        String _tripleSpace_48 = this._common.tripleSpace(2);
        _builder.append(_tripleSpace_48);
        CharSequence _xmlGeneratedTag_4 = this._common.xmlGeneratedTag();
        _builder.append(_xmlGeneratedTag_4);
        _builder.newLineIfNotEmpty();
        String _tripleSpace_49 = this._common.tripleSpace(2);
        _builder.append(_tripleSpace_49);
        _builder.append("<decoratorProvider class=\"");
        CharSequence _qualifiedClassName_4 = this.shorcutProvider.qualifiedClassName(it);
        _builder.append(_qualifiedClassName_4);
        _builder.append("\">");
        _builder.newLineIfNotEmpty();
        String _tripleSpace_50 = this._common.tripleSpace(3);
        _builder.append(_tripleSpace_50);
        _builder.append("<Priority name=\"");
        ProviderPriority _shortcutsDecoratorProviderPriority = it.getShortcutsDecoratorProviderPriority();
        _builder.append(_shortcutsDecoratorProviderPriority);
        _builder.append("\"/>");
        _builder.newLineIfNotEmpty();
        String _tripleSpace_51 = this._common.tripleSpace(3);
        _builder.append(_tripleSpace_51);
        _builder.append("<object class=\"org.eclipse.gmf.runtime.notation.Node(org.eclipse.gmf.runtime.notation)\" id=\"generated-top-nodes\">");
        _builder.newLineIfNotEmpty();
        String _tripleSpace_52 = this._common.tripleSpace(4);
        _builder.append(_tripleSpace_52);
        _builder.append("<method name=\"getType()\" value=\"");
        CharSequence _commaSeparatedVisualIDs_6 = this.commaSeparatedVisualIDs(it.getTopLevelNodes());
        _builder.append(_commaSeparatedVisualIDs_6);
        _builder.append("\"/>");
        _builder.newLineIfNotEmpty();
        String _tripleSpace_53 = this._common.tripleSpace(3);
        _builder.append(_tripleSpace_53);
        _builder.append("</object>");
        _builder.newLineIfNotEmpty();
        String _tripleSpace_54 = this._common.tripleSpace(3);
        _builder.append(_tripleSpace_54);
        _builder.append("<context decoratorTargets=\"generated-top-nodes\"/>");
        _builder.newLineIfNotEmpty();
        String _tripleSpace_55 = this._common.tripleSpace(2);
        _builder.append(_tripleSpace_55);
        _builder.append("</decoratorProvider>");
        _builder.newLineIfNotEmpty();
        String _tripleSpace_56 = this._common.tripleSpace(1);
        _builder.append(_tripleSpace_56);
        _builder.append("</extension>");
        _builder.newLineIfNotEmpty();
      }
    }
    _builder.newLine();
    String _tripleSpace_57 = this._common.tripleSpace(1);
    _builder.append(_tripleSpace_57);
    _builder.append("<extension point=\"org.eclipse.gmf.runtime.emf.type.core.elementTypes\" id=\"element-types\">");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_58 = this._common.tripleSpace(2);
    _builder.append(_tripleSpace_58);
    CharSequence _xmlGeneratedTag_5 = this._common.xmlGeneratedTag();
    _builder.append(_xmlGeneratedTag_5);
    _builder.newLineIfNotEmpty();
    {
      List<GenCommonBase> _allTypedElements = this._utils_qvto.getAllTypedElements(it);
      for(final GenCommonBase e : _allTypedElements) {
        CharSequence _elementTypeSafe = this.elementTypeSafe(e.getElementType());
        _builder.append(_elementTypeSafe);
        _builder.newLineIfNotEmpty();
      }
    }
    String _tripleSpace_59 = this._common.tripleSpace(1);
    _builder.append(_tripleSpace_59);
    _builder.append("</extension>");
    _builder.newLineIfNotEmpty();
    _builder.newLine();
    String _tripleSpace_60 = this._common.tripleSpace(1);
    _builder.append(_tripleSpace_60);
    _builder.append("<extension point=\"org.eclipse.gmf.runtime.emf.type.core.elementTypeBindings\" id=\"element-types-bindings\">");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_61 = this._common.tripleSpace(2);
    _builder.append(_tripleSpace_61);
    CharSequence _xmlGeneratedTag_6 = this._common.xmlGeneratedTag();
    _builder.append(_xmlGeneratedTag_6);
    _builder.newLineIfNotEmpty();
    String _tripleSpace_62 = this._common.tripleSpace(2);
    _builder.append(_tripleSpace_62);
    _builder.append("<clientContext id=\"");
    String _iD = it.getEditorGen().getPlugin().getID();
    _builder.append(_iD);
    _builder.append(".TypeContext\">");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_63 = this._common.tripleSpace(3);
    _builder.append(_tripleSpace_63);
    _builder.append("<enablement>");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_64 = this._common.tripleSpace(4);
    _builder.append(_tripleSpace_64);
    _builder.append("<test");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_65 = this._common.tripleSpace(5);
    _builder.append(_tripleSpace_65);
    _builder.append("property=\"org.eclipse.gmf.runtime.emf.core.editingDomain\"");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_66 = this._common.tripleSpace(5);
    _builder.append(_tripleSpace_66);
    _builder.append("value=\"");
    String _editingDomainID = it.getEditingDomainID();
    _builder.append(_editingDomainID);
    _builder.append("\"/>");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_67 = this._common.tripleSpace(3);
    _builder.append(_tripleSpace_67);
    _builder.append("</enablement>");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_68 = this._common.tripleSpace(2);
    _builder.append(_tripleSpace_68);
    _builder.append("</clientContext> ");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_69 = this._common.tripleSpace(2);
    _builder.append(_tripleSpace_69);
    _builder.append("<binding context=\"");
    String _iD_1 = it.getEditorGen().getPlugin().getID();
    _builder.append(_iD_1);
    _builder.append(".TypeContext\">");
    _builder.newLineIfNotEmpty();
    {
      List<GenCommonBase> _allTypedElements_1 = this._utils_qvto.getAllTypedElements(it);
      for(final GenCommonBase e_1 : _allTypedElements_1) {
        String _tripleSpace_70 = this._common.tripleSpace(3);
        _builder.append(_tripleSpace_70);
        _builder.append("<elementType ref=\"");
        String _uniqueIdentifier = e_1.getElementType().getUniqueIdentifier();
        _builder.append(_uniqueIdentifier);
        _builder.append("\"/>");
        _builder.newLineIfNotEmpty();
      }
    }
    String _tripleSpace_71 = this._common.tripleSpace(3);
    _builder.append(_tripleSpace_71);
    _builder.append("<advice ref=\"org.eclipse.gmf.runtime.diagram.core.advice.notationDepdendents\"/>");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_72 = this._common.tripleSpace(2);
    _builder.append(_tripleSpace_72);
    _builder.append("</binding>");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_73 = this._common.tripleSpace(1);
    _builder.append(_tripleSpace_73);
    _builder.append("</extension>");
    _builder.newLineIfNotEmpty();
    return _builder;
  }
  
  public CharSequence elementTypeSafe(final ElementType it) {
    StringConcatenation _builder = new StringConcatenation();
    {
      boolean _isDefinedExternally = it.isDefinedExternally();
      boolean _not = (!_isDefinedExternally);
      if (_not) {
        CharSequence _elementType = this.elementType(it);
        _builder.append(_elementType);
        _builder.newLineIfNotEmpty();
      }
    }
    return _builder;
  }
  
  protected CharSequence _elementType(final ElementType it) {
    StringConcatenation _builder = new StringConcatenation();
    this._common_qvto.ERROR(("Unknown element type: " + it));
    return _builder;
  }
  
  protected CharSequence _elementType(final MetamodelType it) {
    StringConcatenation _builder = new StringConcatenation();
    String _tripleSpace = this._common.tripleSpace(2);
    _builder.append(_tripleSpace);
    _builder.append("<metamodel nsURI=\"");
    String _nsURI = it.getMetaClass().getGenPackage().getEcorePackage().getNsURI();
    _builder.append(_nsURI);
    _builder.append("\">");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_1 = this._common.tripleSpace(3);
    _builder.append(_tripleSpace_1);
    _builder.append("<metamodelType");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_2 = this._common.tripleSpace(5);
    _builder.append(_tripleSpace_2);
    _builder.append("id=\"");
    String _uniqueIdentifier = it.getUniqueIdentifier();
    _builder.append(_uniqueIdentifier);
    _builder.append("\"");
    _builder.newLineIfNotEmpty();
    {
      String _displayName = it.getDisplayName();
      boolean _notEquals = (!Objects.equal(null, _displayName));
      if (_notEquals) {
        String _tripleSpace_3 = this._common.tripleSpace(5);
        _builder.append(_tripleSpace_3);
        _builder.append("name=\"%metatype.name.");
        String _uniqueIdentifier_1 = it.getDiagramElement().getUniqueIdentifier();
        _builder.append(_uniqueIdentifier_1);
        _builder.append("\"");
        _builder.newLineIfNotEmpty();
      }
    }
    String _tripleSpace_4 = this._common.tripleSpace(5);
    _builder.append(_tripleSpace_4);
    _builder.append("kind=\"org.eclipse.gmf.runtime.emf.type.core.IHintedType\"");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_5 = this._common.tripleSpace(5);
    _builder.append(_tripleSpace_5);
    _builder.append("eclass=\"");
    String _name = it.getMetaClass().getEcoreClass().getName();
    _builder.append(_name);
    _builder.append("\"");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_6 = this._common.tripleSpace(5);
    _builder.append(_tripleSpace_6);
    _builder.append("edithelper=\"");
    CharSequence _qualifiedClassName = this.editHelper.qualifiedClassName(it);
    _builder.append(_qualifiedClassName);
    _builder.append("\">");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_7 = this._common.tripleSpace(4);
    _builder.append(_tripleSpace_7);
    _builder.append("<param name=\"semanticHint\" value=\"");
    int _visualID = it.getDiagramElement().getVisualID();
    _builder.append(_visualID);
    _builder.append("\"/>");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_8 = this._common.tripleSpace(3);
    _builder.append(_tripleSpace_8);
    _builder.append("</metamodelType>");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_9 = this._common.tripleSpace(2);
    _builder.append(_tripleSpace_9);
    _builder.append("</metamodel>");
    _builder.newLineIfNotEmpty();
    return _builder;
  }
  
  protected CharSequence _elementType(final SpecializationType it) {
    StringConcatenation _builder = new StringConcatenation();
    {
      GenClass _metamodelClass = it.getMetamodelClass();
      boolean _equals = Objects.equal(null, _metamodelClass);
      if (_equals) {
        CharSequence _specializationType = this.specializationType(it);
        _builder.append(_specializationType);
        _builder.newLineIfNotEmpty();
      } else {
        String _tripleSpace = this._common.tripleSpace(2);
        _builder.append(_tripleSpace);
        _builder.append("<metamodel nsURI=\"");
        String _nsURI = it.getMetamodelClass().getGenPackage().getEcorePackage().getNsURI();
        _builder.append(_nsURI);
        _builder.append("\">");
        _builder.newLineIfNotEmpty();
        CharSequence _specializationType_1 = this.specializationType(it);
        _builder.append(_specializationType_1);
        _builder.newLineIfNotEmpty();
        String _tripleSpace_1 = this._common.tripleSpace(2);
        _builder.append(_tripleSpace_1);
        _builder.append("</metamodel>");
        _builder.newLineIfNotEmpty();
      }
    }
    return _builder;
  }
  
  public CharSequence specializationType(final SpecializationType it) {
    StringConcatenation _builder = new StringConcatenation();
    String _tripleSpace = this._common.tripleSpace(3);
    _builder.append(_tripleSpace);
    _builder.append("<specializationType");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_1 = this._common.tripleSpace(5);
    _builder.append(_tripleSpace_1);
    _builder.append("id=\"");
    String _uniqueIdentifier = it.getUniqueIdentifier();
    _builder.append(_uniqueIdentifier);
    _builder.append("\"");
    _builder.newLineIfNotEmpty();
    {
      String _displayName = it.getDisplayName();
      boolean _notEquals = (!Objects.equal(null, _displayName));
      if (_notEquals) {
        String _tripleSpace_2 = this._common.tripleSpace(5);
        _builder.append(_tripleSpace_2);
        _builder.append("name=\"%metatype.name.");
        String _uniqueIdentifier_1 = it.getDiagramElement().getUniqueIdentifier();
        _builder.append(_uniqueIdentifier_1);
        _builder.append("\"");
        _builder.newLineIfNotEmpty();
      }
    }
    String _tripleSpace_3 = this._common.tripleSpace(5);
    _builder.append(_tripleSpace_3);
    _builder.append("kind=\"org.eclipse.gmf.runtime.emf.type.core.IHintedType\"");
    {
      String _editHelperAdviceClassName = it.getEditHelperAdviceClassName();
      boolean _notEquals_1 = (!Objects.equal(_editHelperAdviceClassName, null));
      if (_notEquals_1) {
        _builder.newLineIfNotEmpty();
        String _tripleSpace_4 = this._common.tripleSpace(5);
        _builder.append(_tripleSpace_4);
        _builder.append("edithelperadvice=\"");
        CharSequence _qualifiedClassName = this.editHelperAdvice.qualifiedClassName(it);
        _builder.append(_qualifiedClassName);
        _builder.append("\"");
      }
    }
    _builder.append(">");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_5 = this._common.tripleSpace(4);
    _builder.append(_tripleSpace_5);
    _builder.append("<specializes id=\"");
    {
      MetamodelType _metamodelType = it.getMetamodelType();
      boolean _equals = Objects.equal(null, _metamodelType);
      if (_equals) {
        _builder.append("org.eclipse.gmf.runtime.emf.type.core.null");
      } else {
        String _uniqueIdentifier_2 = it.getMetamodelType().getUniqueIdentifier();
        _builder.append(_uniqueIdentifier_2);
      }
    }
    _builder.append("\"/>");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_6 = this._common.tripleSpace(4);
    _builder.append(_tripleSpace_6);
    _builder.append("<param name=\"semanticHint\" value=\"");
    int _visualID = it.getDiagramElement().getVisualID();
    _builder.append(_visualID);
    _builder.append("\"/>");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_7 = this._common.tripleSpace(3);
    _builder.append(_tripleSpace_7);
    _builder.append("</specializationType>");
    _builder.newLineIfNotEmpty();
    return _builder;
  }
  
  protected CharSequence _elementType(final NotationType it) {
    StringConcatenation _builder = new StringConcatenation();
    String _tripleSpace = this._common.tripleSpace(2);
    _builder.append(_tripleSpace);
    _builder.append("<specializationType");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_1 = this._common.tripleSpace(4);
    _builder.append(_tripleSpace_1);
    _builder.append("id=\"");
    String _uniqueIdentifier = it.getUniqueIdentifier();
    _builder.append(_uniqueIdentifier);
    _builder.append("\"");
    _builder.newLineIfNotEmpty();
    {
      String _displayName = it.getDisplayName();
      boolean _notEquals = (!Objects.equal(null, _displayName));
      if (_notEquals) {
        String _tripleSpace_2 = this._common.tripleSpace(4);
        _builder.append(_tripleSpace_2);
        _builder.append("name=\"%metatype.name.");
        String _uniqueIdentifier_1 = it.getDiagramElement().getUniqueIdentifier();
        _builder.append(_uniqueIdentifier_1);
        _builder.append("\"");
        _builder.newLineIfNotEmpty();
      }
    }
    String _tripleSpace_3 = this._common.tripleSpace(4);
    _builder.append(_tripleSpace_3);
    _builder.append("kind=\"org.eclipse.gmf.runtime.diagram.ui.util.INotationType\">");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_4 = this._common.tripleSpace(3);
    _builder.append(_tripleSpace_4);
    _builder.append("<specializes id=\"org.eclipse.gmf.runtime.emf.type.core.null\"/>");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_5 = this._common.tripleSpace(3);
    _builder.append(_tripleSpace_5);
    _builder.append("<param name=\"semanticHint\" value=\"");
    int _visualID = it.getDiagramElement().getVisualID();
    _builder.append(_visualID);
    _builder.append("\"/>");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_6 = this._common.tripleSpace(2);
    _builder.append(_tripleSpace_6);
    _builder.append("</specializationType>");
    _builder.newLineIfNotEmpty();
    return _builder;
  }
  
  public CharSequence modelingAssistantProvider(final GenDiagram it) {
    StringConcatenation _builder = new StringConcatenation();
    _builder.append("<extension point=\"org.eclipse.gmf.runtime.emf.ui.modelingAssistantProviders\" id=\"modelassist-provider\">");
    _builder.newLine();
    _builder.append("\t");
    CharSequence _xmlGeneratedTag = this._common.xmlGeneratedTag();
    _builder.append(_xmlGeneratedTag, "\t");
    _builder.newLineIfNotEmpty();
    _builder.append("\t");
    _builder.append("<modelingAssistantProvider class=\"");
    CharSequence _modelingAssistantProviderQualifiedClassName = this.modelingAssistantProviderQualifiedClassName(it);
    _builder.append(_modelingAssistantProviderQualifiedClassName, "\t");
    _builder.append("\">");
    _builder.newLineIfNotEmpty();
    _builder.append("\t\t");
    _builder.append("<Priority name=\"");
    ProviderPriority _modelingAssistantProviderPriority = it.getModelingAssistantProviderPriority();
    _builder.append(_modelingAssistantProviderPriority, "\t\t");
    _builder.append("\"/>");
    _builder.newLineIfNotEmpty();
    _builder.append("\t\t");
    _builder.append("<object class=\"");
    String _editPartQualifiedClassName = it.getEditPartQualifiedClassName();
    _builder.append(_editPartQualifiedClassName, "\t\t");
    _builder.append("\" id=\"");
    String _uniqueIdentifier = it.getUniqueIdentifier();
    _builder.append(_uniqueIdentifier, "\t\t");
    _builder.append("\"/>");
    _builder.newLineIfNotEmpty();
    _builder.append("\t\t");
    _builder.append("<context elements=\"");
    String _uniqueIdentifier_1 = it.getUniqueIdentifier();
    _builder.append(_uniqueIdentifier_1, "\t\t");
    _builder.append("\"/>");
    _builder.newLineIfNotEmpty();
    _builder.append("\t");
    _builder.append("</modelingAssistantProvider>");
    _builder.newLine();
    {
      EList<GenNode> _allNodes = it.getAllNodes();
      for(final GenNode n : _allNodes) {
        _builder.append("\t");
        _builder.append("<modelingAssistantProvider class=\"");
        CharSequence _modelingAssistantProviderQualifiedClassName_1 = this.modelingAssistantProviderQualifiedClassName(n);
        _builder.append(_modelingAssistantProviderQualifiedClassName_1, "\t");
        _builder.append("\">");
        _builder.newLineIfNotEmpty();
        _builder.append("\t");
        _builder.append("\t");
        _builder.append("<Priority name=\"");
        ProviderPriority _modelingAssistantProviderPriority_1 = n.getDiagram().getModelingAssistantProviderPriority();
        _builder.append(_modelingAssistantProviderPriority_1, "\t\t");
        _builder.append("\"/>");
        _builder.newLineIfNotEmpty();
        _builder.append("\t");
        _builder.append("\t");
        _builder.append("<object class=\"");
        String _editPartQualifiedClassName_1 = n.getEditPartQualifiedClassName();
        _builder.append(_editPartQualifiedClassName_1, "\t\t");
        _builder.append("\" id=\"");
        String _uniqueIdentifier_2 = n.getUniqueIdentifier();
        _builder.append(_uniqueIdentifier_2, "\t\t");
        _builder.append("\"/>");
        _builder.newLineIfNotEmpty();
        _builder.append("\t");
        _builder.append("\t");
        _builder.append("<context elements=\"");
        String _uniqueIdentifier_3 = n.getUniqueIdentifier();
        _builder.append(_uniqueIdentifier_3, "\t\t");
        _builder.append("\"/>");
        _builder.newLineIfNotEmpty();
        _builder.append("\t");
        _builder.append("</modelingAssistantProvider>");
        _builder.newLine();
      }
    }
    _builder.append("</extension>");
    _builder.newLine();
    return _builder;
  }
  
  @MetaDef
  protected CharSequence _modelingAssistantProviderQualifiedClassName(final GenContainerBase it) {
    StringConcatenation _builder = new StringConcatenation();
    return _builder;
  }
  
  @MetaDef
  protected CharSequence _modelingAssistantProviderQualifiedClassName(final GenDiagram it) {
    StringConcatenation _builder = new StringConcatenation();
    CharSequence _qualifiedClassName = this.xptEditPartModelingAssistant.qualifiedClassName(it);
    _builder.append(_qualifiedClassName);
    return _builder;
  }
  
  @MetaDef
  protected CharSequence _modelingAssistantProviderQualifiedClassName(final GenNode it) {
    StringConcatenation _builder = new StringConcatenation();
    CharSequence _qualifiedClassName = this.xptEditPartModelingAssistant.qualifiedClassName(it);
    _builder.append(_qualifiedClassName);
    return _builder;
  }
  
  public CharSequence commaSeparatedVisualIDs(final Iterable<? extends GenCommonBase> list) {
    StringConcatenation _builder = new StringConcatenation();
    {
      boolean _hasElements = false;
      for(final GenCommonBase gcb : list) {
        if (!_hasElements) {
          _hasElements = true;
        } else {
          _builder.appendImmediate(",", "");
        }
        int _visualID = gcb.getVisualID();
        _builder.append(_visualID);
      }
    }
    return _builder;
  }
  
  @Localization
  public CharSequence i18n(final GenDiagram it) {
    StringConcatenation _builder = new StringConcatenation();
    _builder.newLine();
    _builder.append("# Providers");
    _builder.newLine();
    {
      final Function1<GenCommonBase, ElementType> _function = new Function1<GenCommonBase, ElementType>() {
        @Override
        public ElementType apply(final GenCommonBase t) {
          return t.getElementType();
        }
      };
      List<ElementType> _map = ListExtensions.<GenCommonBase, ElementType>map(this._utils_qvto.getAllTypedElements(it), _function);
      for(final ElementType next : _map) {
        CharSequence _internal_i18n = this.internal_i18n(next);
        _builder.append(_internal_i18n);
      }
    }
    CharSequence _extraLineBreak = this._common.extraLineBreak();
    _builder.append(_extraLineBreak);
    _builder.newLineIfNotEmpty();
    return _builder;
  }
  
  @Localization
  public CharSequence internal_i18n(final ElementType it) {
    StringConcatenation _builder = new StringConcatenation();
    {
      if (((!Objects.equal(null, it.getDisplayName())) && (!it.isDefinedExternally()))) {
        _builder.append("metatype.name.");
        String _uniqueIdentifier = it.getDiagramElement().getUniqueIdentifier();
        _builder.append(_uniqueIdentifier);
        _builder.append("=");
        String _displayName = it.getDisplayName();
        _builder.append(_displayName);
      }
    }
    _builder.newLineIfNotEmpty();
    return _builder;
  }
  
  public CharSequence elementType(final ElementType it) {
    if (it instanceof MetamodelType) {
      return _elementType((MetamodelType)it);
    } else if (it instanceof NotationType) {
      return _elementType((NotationType)it);
    } else if (it instanceof SpecializationType) {
      return _elementType((SpecializationType)it);
    } else if (it != null) {
      return _elementType(it);
    } else {
      throw new IllegalArgumentException("Unhandled parameter types: " +
        Arrays.<Object>asList(it).toString());
    }
  }
  
  public CharSequence modelingAssistantProviderQualifiedClassName(final GenContainerBase it) {
    if (it instanceof GenNode) {
      return _modelingAssistantProviderQualifiedClassName((GenNode)it);
    } else if (it instanceof GenDiagram) {
      return _modelingAssistantProviderQualifiedClassName((GenDiagram)it);
    } else if (it != null) {
      return _modelingAssistantProviderQualifiedClassName(it);
    } else {
      throw new IllegalArgumentException("Unhandled parameter types: " +
        Arrays.<Object>asList(it).toString());
    }
  }
}
